@@ -319,6 +319,10 @@ static int fill_lgr_struct(struct smc_diag_lgr *lgr, struct nlattr **attrs)
 	if (lgr_attrs[SMC_NLA_LGR_R_PNETID])
 		snprintf((char*)lgr->pnet_id, sizeof(lgr->pnet_id), "%s",
 			 nla_get_string(lgr_attrs[SMC_NLA_LGR_R_PNETID]));
+	if (lgr_attrs[SMC_NLA_LGR_R_SNDBUF_ALLOC])
+		lgr->sndbuf_alloc = nl_attr_get_uint(lgr_attrs[SMC_NLA_LGR_R_SNDBUF_ALLOC]);
+	if (lgr_attrs[SMC_NLA_LGR_R_RMB_ALLOC])
+		lgr->rmb_alloc = nl_attr_get_uint(lgr_attrs[SMC_NLA_LGR_R_RMB_ALLOC]);
 	if (lgr_attrs[SMC_NLA_LGR_R_V2_COMMON]) {
 		struct nlattr *v2_lgr_attrs[SMC_NLA_LGR_V2_MAX + 1];
 
@@ -365,6 +369,10 @@ static int fill_lgr_smcd_struct(struct smcd_diag_dmbinfo_v2 *lgr, struct nlattr
 	if (lgr_attrs[SMC_NLA_LGR_D_PNETID])
 		snprintf((char*)lgr->pnet_id, sizeof(lgr->pnet_id), "%s",
 			 nla_get_string(lgr_attrs[SMC_NLA_LGR_D_PNETID]));
+	if (lgr_attrs[SMC_NLA_LGR_D_SNDBUF_ALLOC])
+		lgr->sndbuf_alloc = nl_attr_get_uint(lgr_attrs[SMC_NLA_LGR_D_SNDBUF_ALLOC]);
+	if (lgr_attrs[SMC_NLA_LGR_D_DMB_ALLOC])
+		lgr->dmb_alloc = nl_attr_get_uint(lgr_attrs[SMC_NLA_LGR_D_DMB_ALLOC]);
 	if (lgr_attrs[SMC_NLA_LGR_D_V2_COMMON]) {
 		struct nlattr *v2_lgr_attrs[SMC_NLA_LGR_V2_MAX + 1];
 
@@ -402,6 +410,8 @@ static void show_lgr_smcr_info_lgr_details(struct smc_diag_lgr *lgr)
 		printf("EID      : %s\n", lgr->v2_lgr_info.negotiated_eid);
 	}
 	printf("#Conns   : %d\n", lgr->conns_num);
+	printf("Sndbuf   : %lld B\n", lgr->sndbuf_alloc);
+	printf("RMB      : %lld B\n", lgr->rmb_alloc);
 }
 
 static int show_lgr_smcr_info(struct nlattr **attr)
@@ -482,6 +492,8 @@ static void show_lgr_smcd_info_lgr_details(struct smcd_diag_dmbinfo_v2 *lgr)
 		printf("EID      : %s\n", lgr->v2_lgr_info.negotiated_eid);
 	}
 	printf("#Conns   : %d\n", lgr->conns_num);
+	printf("Sndbuf   : %lld B\n", lgr->sndbuf_alloc);
+	printf("DMB      : %lld B\n", lgr->dmb_alloc);
 }
 
 static int show_lgr_smcd_info(struct nlattr **attr)
